@@ -18,6 +18,7 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
+#include <string>
 #include <stdlib.h>
 
 #include "base256.h"
@@ -38,9 +39,9 @@ void base256::init()
 // this function substitutes a two character sequence for the offending
 // characters
 //----------------------------------------------------------------------
-void base256::escape(string &in, bool encode)
+void base256::escape(std::string &in, bool encode)
 {
-	string out;
+	std::string out;
 	if (encode) {
 		for( size_t i = 0; i < in.length(); i++) {
 			switch ((in[i] & 0xFF)) {
@@ -94,9 +95,9 @@ void base256::escape(string &in, bool encode)
 	in = out;
 }
 
-void base256::addlf(string &in)
+void base256::addlf(std::string &in)
 {
-	string out;
+	std::string out;
 	int len = 0;
 	for (size_t n = 0; n < in.length(); n++) {
 		if (len < LINELEN) {out += in[n]; len++;}
@@ -105,16 +106,16 @@ void base256::addlf(string &in)
 	in.assign(out);
 }
 
-void base256::remlf(string &in)
+void base256::remlf(std::string &in)
 {
-	string out;
+	std::string out;
 	for (size_t n = 0; n < in.length(); n++) {
 		if (in[n] != '\n') out += in[n];
 	}
 	in.assign(out);
 }
 
-string base256::encode(string &in)
+std::string base256::encode(std::string &in)
 {
 	char insize[20];
 	long n = static_cast<long>(in.length());
@@ -124,19 +125,19 @@ string base256::encode(string &in)
 	iocp = 0;
 	ateof = false;
 
-	string temp (in);
+	std::string temp (in);
 	escape (temp);
 	addlf(temp);
 	output.append(temp);
 	return output;
 }
 
-string base256::decode(string &in)
+std::string base256::decode(std::string &in)
 {
 //	size_t nbr = 0;
-	string output = in;
+	std::string output = in;
 	size_t p = output.find("\n");
-	if (p == string::npos)
+	if (p == std::string::npos)
 		return "ERROR: base256 missing character count";
 //	sscanf(output.substr(0, p).c_str(), "%lu", &nbr);
 	output.erase(0, p+1);
