@@ -7,7 +7,7 @@
 // Copyright (C) 2008-2009
 //              Dave Freese, W1HKJ
 //
-// This file is part of flmsg.
+// This file is part of FLAMP.
 //
 // This is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -27,7 +27,6 @@
 #include <config.h>
 
 #include <cstring>
-#include <string>
 #include <cstdlib>
 #include <cstdio>
 #include <cmath>
@@ -54,6 +53,7 @@
 #include "debug.h"
 
 
+
 /// FTextBase constructor.
 /// Word wrapping is enabled by default at column 80, but see \c reset_wrap_col.
 /// @param x
@@ -62,15 +62,9 @@
 /// @param h
 /// @param l
 
-#if flmsg_FLTK_API_MAJOR == 1 && flmsg_FLTK_API_MINOR < 3
-FTextBase::FTextBase(int x, int y, int w, int h, const char *l)
-: Fl_Text_Editor_mod(x, y, w, h, l),
-wrap(true), wrap_col(80), max_lines(0), scroll_hint(false)
-#else
 FTextBase::FTextBase(int x, int y, int w, int h, const char *l)
 : Fl_Text_Editor_mod(x, y, w, h, l),
 wrap(WRAP_AT_BOUNDS), wrap_col(80), max_lines(0), scroll_hint(false)
-#endif
 {
 	oldw = oldh = olds = -1;
 	oldf = (Fl_Font)-1;
@@ -149,15 +143,9 @@ void FTextBase::add(unsigned char c, int attr)
 
 void FTextBase::set_word_wrap(bool b)
 {
-#if flmsg_FLTK_API_MAJOR == 1 && flmsg_FLTK_API_MINOR < 3
-	if ((wrap = b)) wrap_mode(true, 0);
-	else wrap_mode(false, 0);
-	show_insert_position();
-#else
 	if ((wrap = b)) wrap_mode(WRAP_AT_BOUNDS, 0);
 	else wrap_mode(WRAP_NONE, 0);
 	show_insert_position();
-#endif
 }
 
 void FTextBase::setFont(Fl_Font f, int attr)
@@ -207,7 +195,6 @@ void FTextBase::resize(int X, int Y, int W, int H)
 	if (need_wrap_reset)
 		reset_wrap_col();
 
-#if flmsg_FLTK_API_MAJOR == 1 && flmsg_FLTK_API_MINOR == 3
 	TOP_MARGIN = DEFAULT_TOP_MARGIN;
 	int r = H - Fl::box_dh(box()) - TOP_MARGIN - BOTTOM_MARGIN;
 	if (mHScrollBar->visible())
@@ -217,16 +204,7 @@ void FTextBase::resize(int X, int Y, int W, int H)
 	//printf("H %d, textsize %d, lines %d, extra %d\n", r, msize, r / msize, r % msize);
 	if (r %= msize)
 		TOP_MARGIN += r;
-#else
-	if (need_margin_reset && textsize() > 0) {
-		TOP_MARGIN = DEFAULT_TOP_MARGIN;
-		int r = H - Fl::box_dh(box()) - TOP_MARGIN - BOTTOM_MARGIN;
-		if (mHScrollBar->visible())
-			r -= scrollbar_width();
-		if (r %= textsize())
-			TOP_MARGIN += r;
-	}
-#endif
+
 	if (scroll_hint) {
 		mTopLineNumHint = mNBufferLines;
 		mHorizOffsetHint = 0;
@@ -911,7 +889,7 @@ void FTextEdit::changed_cb(int pos, int nins, int ndel, int nsty, const char *dt
 		}
 		else if (nsty > 0) // restyled, e.g. selected, text
 			return e->buffer_modified_cb(pos, nins, ndel, nsty, dtext, e);
-		
+
 		// No changes, e.g., a paste with an empty clipboard.
 		return;
 	}
@@ -933,9 +911,9 @@ void FTextEdit::changed_cb(int pos, int nins, int ndel, int nsty, const char *dt
 	}
 	else if (ndel > 0)
 		e->sbuf->remove(pos, pos + ndel);
-	
+
 	e->sbuf->select(pos, pos + nins - ndel);
-	
+
 	e->buffer_modified_cb(pos, nins, ndel, nsty, dtext, e);
 	// We may need to scroll if the text was inserted by the
 	// add() methods, e.g. by a macro
