@@ -22,13 +22,13 @@
 
 #include <iostream>
 #include <cstring>
+#include <string>
 #include <ctime>
 #include <cstdio>
+#include <fstream>
 
 #include "date.h"
 
-using namespace std;
-
 const int Date::mdays[] = 
 	{ 0, 31, 28, 31, 30,  31,  30,  31,  31,  30,  31,  30, 31 };
 
@@ -308,7 +308,7 @@ char *Date::szDate ()
 
 // operator functions
 
-ostream &operator<<( ostream &output, Date &d )
+std::ostream &operator<<( std::ostream &output, Date &d )
 {
 	output << d.szDate ();
 	return output;
